@@ -68,7 +68,7 @@ class KReparentingProxyModelPrivate
       If @p model is 0, the sourceModel is used
       Returns an invalid index if there is no index below @p index.
     */
-    QModelIndex getIndexBelow(const QModelIndex &index, QAbstractItemModel *model = 0) const;
+    QModelIndex getIndexBelow(const QModelIndex &index, QAbstractItemModel *model = nullptr) const;
 
     /**
       Returns the last descendant of @p index or itself if it has no children
@@ -539,7 +539,7 @@ QModelIndex KReparentingProxyModel::mapToSource(const QModelIndex &proxyIndex) c
     if (d->m_pendingRemovalChildIndexes.contains(sourceParent)) {
 //     qDebug() << "#############";
 
-        Q_FOREACH (KReparentingProxyModelPrivate::PendingRemoval pendingRemoval, d->m_pendingRemovals) {
+        Q_FOREACH (const KReparentingProxyModelPrivate::PendingRemoval &pendingRemoval, d->m_pendingRemovals) {
 //       qDebug() << "In" << pendingRemoval.index << pendingRemoval.sourceIndex << sourceParent;
             if (pendingRemoval.sourceIndex == sourceParent) {
 //         qDebug() << "Out" << pendingRemoval.sourceIndex << sourceParent;
